@@ -1,10 +1,13 @@
 """
 This module contains our customizatiosn to nbclient and papermill.
 """
-__version__ = '0.0.1'
+__version__ = '0.0.3'
 
 import typing as t
 
+# NOTE: fully initialize papermill here to prevent circular import
+import papermill  # noqa
+
 from jupyter_client import KernelManager
 from nbformat import NotebookNode
 
